@@ -8,17 +8,19 @@
 // Software.
 
 use super::fetch::Range;
-use crate::{ipc::BootstrapConfig, Error, Result};
+use crate::{app::SELF_ENCRYPTION_MIN_SIZE, ipc::NodeConfig, Error, Result};
+use bytes::Bytes;
 use hex::encode;
 use log::{debug, info};
+use safe_network::client::client_api::{Blob, BlobAddress, Spot, SpotAddress};
 use safe_network::client::{Client, Config, Error as ClientError};
 use safe_network::types::{
     register::{Address, Entry, EntryHash, PrivatePermissions, PublicPermissions, User},
-    ChunkAddress, Error as SafeNdError, Keypair,
+    Error as SafeNdError, Keypair,
 };
+use safe_network::url::Scope;
 use std::{
-    collections::{BTreeMap, BTreeSet, HashSet},
-    net::SocketAddr,
+    collections::{BTreeMap, BTreeSet},
     path::{Path, PathBuf},
     time::Duration,
 };
@@ -29,7 +31,6 @@ const APP_NOT_CONNECTED: &str = "Application is not connected to the network";
 #[derive(Default, Clone)]
 pub struct SafeAppClient {
     safe_client: Option<Client>,
-    pub(crate) bootstrap_config: Option<HashSet<SocketAddr>>,
     config_path: Option<PathBuf>,
     timeout: Duration,
 }
@@ -46,7 +47,6 @@ impl SafeAppClient {
     pub fn new(timeout: Duration) -> Self {
         Self {
             safe_client: None,
-            bootstrap_config: None,
             config_path: None,
             timeout,
         }
@@ -58,12 +58,9 @@ impl SafeAppClient {
         &mut self,
         app_keypair: Option<Keypair>,
         config_path: Option<&Path>,
-        bootstrap_config: Option<BootstrapConfig>,
+        node_config: NodeConfig,
     ) -> Result<()> {
         debug!("Connecting to SAFE Network...");
-        if bootstrap_config.is_some() {
-            self.bootstrap_config = bootstrap_config;
-        }
 
         self.config_path = config_path.map(|p| p.to_path_buf());
 
@@ -71,19 +68,21 @@ impl SafeAppClient {
             "Client to be instantiated with specific pk?: {:?}",
             app_keypair
         );
-        debug!(
-            "Bootstrap contacts list set to: {:?}",
-            self.bootstrap_config
-        );
+        debug!("Bootstrap contacts list set to: {:?}", node_config);
+
         let config = Config::new(
+            None,
+            None,
+            node_config.0,
             self.config_path.as_deref(),
-            self.bootstrap_config.clone(),
             Some(self.timeout),
         )
         .await;
-        let client = Client::new(app_keypair, config).await.map_err(|err| {
-            Error::ConnectionError(format!("Failed to connect to the SAFE Network: {:?}", err))
-        })?;
+        let client = Client::new(config, node_config.1, app_keypair)
+            .await
+            .map_err(|err| {
+                Error::ConnectionError(format!("Failed to connect to the SAFE Network: {:?}", err))
+            })?;
 
         self.safe_client = Some(client);
 
@@ -96,38 +95,74 @@ impl SafeAppClient {
         Ok(client.keypair())
     }
 
-    // // === Blob operations ===
-    pub async fn store_public_blob(&self, data: &[u8], dry_run: bool) -> Result<XorName> {
+    pub async fn store_public_spot(&self, data: Bytes, dry_run: bool) -> Result<XorName> {
         let address = if dry_run {
-            let (_, address) = Client::blob_data_map(data.to_vec(), None).await?;
-            address
+            SpotAddress::Public(XorName::default())
         } else {
             let client = self.get_safe_client()?;
             client
-                .store_public_blob(data)
-                .await
-                .map_err(|e| Error::NetDataError(format!("Failed to PUT Public Blob: {:?}", e)))?
+                .write_spot_to_network(Spot::new(data.clone())?, Scope::Public)
+                .await?
         };
-
         Ok(*address.name())
     }
 
-    pub async fn get_public_blob(&self, xorname: XorName, range: Range) -> Result<Vec<u8>> {
+    // // === Blob operations ===
+    pub async fn store_public_blob(&self, data: Bytes, dry_run: bool) -> Result<XorName> {
+        let xorname = if dry_run {
+            // I don't see the equivalent API for doing a dry run, so just returning the default
+            // address for now.
+            XorName::default()
+        } else {
+            let client = self.get_safe_client()?;
+            if data.len() < SELF_ENCRYPTION_MIN_SIZE {
+                debug!(
+                    "Data to write is {} bytes so a spot will be written",
+                    data.len()
+                );
+                let address = client
+                    .write_spot_to_network(Spot::new(data.to_owned())?, Scope::Public)
+                    .await
+                    .map_err(|e| {
+                        Error::NetDataError(format!("Failed to PUT Public Blob: {:?}", e))
+                    })?;
+                *address.name()
+            } else {
+                debug!(
+                    "Data to write is {} bytes so a blob will be written",
+                    data.len()
+                );
+                let address = client
+                    .write_blob_to_network(Blob::new(data.to_owned())?, Scope::Public)
+                    .await
+                    .map_err(|e| {
+                        Error::NetDataError(format!("Failed to PUT Public Blob: {:?}", e))
+                    })?;
+                *address.name()
+            }
+        };
+
+        Ok(xorname)
+    }
+
+    pub async fn get_public_blob(&self, xorname: XorName, range: Range) -> Result<Bytes> {
         debug!("Fetching immutable data: {:?}", &xorname);
 
         let client = self.get_safe_client()?;
-        let blob_address = ChunkAddress::Public(xorname);
+        let blob_address = BlobAddress::Public(xorname);
         let data = if let Some((start, end)) = range {
-            let len = end.map(|end_index| end_index - start.unwrap_or(0));
+            let len = end
+                .map(|end_index| end_index - start.unwrap_or(0))
+                .unwrap_or(0);
             client
-                .read_blob(
+                .read_blob_from(
                     blob_address,
-                    start.map(|val| val as usize),
-                    len.map(|val| val as usize),
+                    start.map(|val| val as usize).unwrap_or(0),
+                    len as usize,
                 )
                 .await
         } else {
-            client.read_blob(blob_address, None, None).await
+            client.read_blob(blob_address).await
         }
         .map_err(|e| Error::NetDataError(format!("Failed to GET Public Blob: {:?}", e)))?;
 
