@@ -21,7 +21,7 @@ mod constants;
 mod errors;
 
 // re-export these useful types from sn_data_types
-pub use sn_data_types::{Keypair, PublicKey, SecretKey};
+pub use safe_network::types::{Keypair, PublicKey, SecretKey};
 
 #[cfg(feature = "app")]
 pub use app::*;
